pub type Throwable<T> = Rc<RefCell<T>>;Expand description
A type recommended to be used by FutureQueue to allow being thrown around in your app
Aliased Type
pub struct Throwable<T> { /* private fields */ }pub type Throwable<T> = Rc<RefCell<T>>;A type recommended to be used by FutureQueue to allow being thrown around in your app
pub struct Throwable<T> { /* private fields */ }